﻿import com.kelvinluck.flickr.Flickr;
import com.kelvinluck.flickr.Person;
import com.kelvinluck.flickr.Photo;
import com.kelvinluck.flickr.Tag;
import com.kelvinluck.util.LogWrapper;
import com.kelvinluck.flickr.Photoset;
import com.kelvinluck.flickr.Group;

/**
* Class: com.kelvinluck.flickr.FlickrResponseListener
* Class to define a listener for responses from the FlickrAPI.
* 
* Subclass this class or override the methods you are interested in and
* use Flickr.addListener... The methods as they exist in this class just
* output debugging information and exist kind of like an interface to 
* specify the callbacks from <Flickr.callMethod> and the variables available
* to them.
* 
* This code is licensed under a Creative Commons License.
* http://creativecommons.org/licenses/by-nc-sa/2.0/
* 
* See Also:
* <Flickr>
* 
* <Flickr.callMethod>
* 
* <http://www.flickr.com/services/api/>
* 
* Version:
* 0.3.0
* 
* Author:
* Kelvin Luck < kelvin at kelvinluck dot com >
* 
* Project Website:
* <http://kelvinluck.com/projects/flashr-a-flickr-api-wrapper-for-flash>
**/
class com.kelvinluck.flickr.FlickrResponseListener {
	
	/**
	* Variable: supressOutput
	* 
	* Used internally to control whether info messages are logged.
	* 
	* See Also:
	* <setSuppressOutput>
	**/
	private var supressOutput:Boolean;
	
	function FlickrResponseListener()
	{
		LogWrapper.getLog().debug("com.kelvinluck.flickr.FlickrResponseListener instance created");
		Flickr.getFlickr().addEventListener("onAPIResponse", this);
		supressOutput = false;
	}
	
	/**
	* Function: setSuppressOutput
	* 
	* Use if you don't want this instance to log it's messages.
	* 
	* You may want to do this if you have multipule FlickrResponseListeners
	* in one movie (e.g. one for auth stuff and one for other calls) or in
	* a production environment.
	* 
	* See Also:
	* <supressOutput>
	**/
	function setSuppressOutput(supressOutput:Boolean):Void
	{
		this.supressOutput = supressOutput;
	}
	
// flickr.auth methods

	/**
	* Function: onAuthGetFrob
	* 
	* Called when there is a successful  response from a call to flickr.auth.getFrob
	* 
	* Note that you only need to use this and <Flickr.authGetFrob> if you have opted
	* not to use <Flickr.authLogin> for some reason.
	* 
	* Parameters:
	* frob				-	a frob to be used during authentication.
	* 
	* See Also:
	* <Flickr.authLogin>
	* 
	* <Flickr.authGetFrob>
	* 
	* <http://flickr.com/services/api/flickr.auth.getFrob.html>
	**/
	public function onAuthGetFrob(frob)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onAuthGetFrob: flickr.auth.getFrob");
			LogWrapper.getLog().info("frob = " + frob);
		}
	}

	/**
	* Function: onAuthCheckToken
	* 
	* Called when there is a successful response from a call to flickr.auth.getToken
	* or flickr.auth.checkToken.
	* 
	* The token is returned so that you can save it so that you can authenticate against
	* flickr at a later date without prompting the user again.
	* 
	* Parameters:
	* token				-	the auth token.
	* 
	* See Also:
	* <Flickr.authLogin>
	* 
	* <Flickr.authCheckToken>
	* 
	* <http://www.flickr.com/services/api/flickr.auth.getToken.html>
	* 
	* <http://www.flickr.com/services/api/flickr.auth.checkToken.html>
	**/
	public function onAuthCheckToken(token)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onAuthCheckToken: flickr.auth.checkToken");
			LogWrapper.getLog().info("token = " + token);
		}
	}

// /flickr.auth methods


// flickr.contacts methods
	
	/**
	* Function: onContactsGetList
	* 
	* Called when there is a response from a call to flickr.contacts.getList.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* contacts 			- 	The <Person> whose contacts you collected.
	* 						Use <Person.getPublicContacts> to see their contacts.
	* filter			-	The filter that was used on the call to <Flickr.contactsGetList> or
	* 						undefined if no filter was used.
	* 
	* See Also:
	* <Flickr.contactsGetList>
	* 
	* <http://flickr.com/services/api/flickr.contacts.getList.html>
	**/
	function onContactsGetList(user:Person, filter:String)
	{
		if (!supressOutput) {
			var msg:String = "FlickrResponseListener.onContactsGetList: flickr.contacts.getList";
			if (filter) {
				msg += " - using filter: '"+filter+"'";
			}
			LogWrapper.getLog().info(msg);
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onContactsGetPublicList
	* 
	* Called when there is a response from a call to flickr.contacts.getPublicList.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user 				- 	The <Person> object whose contacts you got. 
	* 						Use <Person.getPublicContacts>
	* 						to retrieve the list of contacts.
	* 
	* See Also:
	* <Flickr.contactsGetPublicList>
	* 
	* <Person.getPublicContacts>
	* 
	* <http://flickr.com/services/api/flickr.contacts.getPublicList.html>
	**/
	function onContactsGetPublicList(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onContactsGetPublicList: flickr.contacts.getPublicList for user "+user.nsid);
			LogWrapper.getLog().info(user);
		}
	}
// /flickr.contacts methods
	
	
// flickr.favorites methods

	/**
	* Function: onFavoritesAdd
	* 
	* Called when there is a response from a call to flickr.favorites.add.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 	- 	The photo which has just been successfully added to the auth'duser's 
	* 				favorites.
	* 
	* See Also:
	* <Flickr.favoritesAdd>
	* 
	* <http://www.flickr.com/services/api/flickr.favorites.add.html>
	**/
	function onFavoritesAdd(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onFavoritesAdd: flickr.favorites.add photo "+photo.id+" added");
		}
	}
	/**
	* Function: onFavoritesGetList
	* 
	* Called when there is a response from a call to flickr.favorites.getList.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user		- 	The <Person> whose favourites we got. You see get their favorites using
	* 				<Person.getFavorites>.
	* 
	* See Also:
	* <Flickr.favoritesGetList>
	* 
	* <Person.getFavorites>
	* 
	* <http://www.flickr.com/services/api/flickr.favorites.getList.html>
	**/
	function onFavoritesGetList(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onFavoritesGetList: flickr.favorites.getList for user "+ user.nsid);
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onFavoritesGetPublicList
	* 
	* Called when there is a response from a call to flickr.favorites.getPublicList.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user			- 	The <Person> whose favourites we got. You can get their favorites using
	* 					<Person.getFavorites>.
	* 
	* See Also:
	* <Flickr.favoritesGetPublicList>
	* 
	* <Person.getFavorites>
	* 
	* <http://www.flickr.com/services/api/flickr.favorites.getPublicList.html>
	**/
	function onFavoritesGetPublicList(user:Person)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onFavoritesGetPublicList: flickr.favorites.getPublicList for user "+ user.nsid;
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onFavoritesRemove
	* 
	* Called when there is a response from a call to flickr.favorites.remove.
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		- 	The photo which has just been successfully removed 
	* 			 	 	from the auth'd user's favorites.
	* 
	* See Also:
	* <Flickr.favoritesRemove>
	* 
	* <http://www.flickr.com/services/api/flickr.favorites.remove.html>
	**/
	function onFavoritesRemove(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onFavoritesRemove: flickr.favorites.remove photo "+photo.id+" removed");
		}
	}
	
// /flickr.favorites methods

// flickr.groups.pools methods
	/**
	* Function: onGroupsPoolsAdd
	* 
	* Called when there is a response from a call to flickr.groups.pools.add
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		- 	The <Photo> you have just added to a <Group>.
	* group			-	The <Group> you have just added the <Photo> to.
	* 
	* See Also:
	* <Flickr.groupsPoolsAdd>
	* 
	* <http://flickr.com/services/api/flickr.groups.pools.add.html>
	**/
	function onGroupsPoolsAdd(photo:Photo, group:Group)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onGroupsPoolsAdd: flickr.groups.pools.add response");
			LogWrapper.getLog().info(photo);
			LogWrapper.getLog().info(group);
		}
		
	}
	/**
	* Function: onGroupsPoolsGetContext
	* 
	* Called when there is a response from a call to flickr.groups.pools.getContext
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		- 	The <Photo> you have just got the context for.
	* group			-	The <Group> you have just got the context in
	* 
	* See Also:
	* <Flickr.groupsPoolsGetContext>
	* 
	* <Photo.contextGroupPools>
	* 
	* <http://flickr.com/services/api/flickr.groups.pools.getContext.html>
	**/
	function onGroupsPoolsGetContext(photo:Photo, group:Group)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onGroupsPoolsGetContext: flickr.groups.pools.getContext response");
			LogWrapper.getLog().info(photo);
			LogWrapper.getLog().info(group);
		}
		
	}
	/**
	* Function: onGroupsPoolsGetGroups
	* 
	* Called when there is a response from a call to flickr.groups.pools.getGroups
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user	 		- 	The <Person> you have just got the <Group>s for.
	* 
	* See Also:
	* <Flickr.groupsPoolsGetGroups>
	* 
	* <Person.getGroups>
	* 
	* <http://flickr.com/services/api/flickr.groups.pools.getGroups.html>
	**/
	function onGroupsPoolsGetGroups(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onGroupsPoolsGetGroups: flickr.groups.pools.getGroups response");
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onGroupsPoolsGetPhotos
	* 
	* Called when there is a response from a call to flickr.groups.pools.getPhotos
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* group				- 	The <Group> you have just got the <Photo>s for.
	* 
	* See Also:
	* <Flickr.groupsPoolsGetPhotos>
	* 
	* <Group.getPhotos>
	* 
	* <http://flickr.com/services/api/flickr.groups.pools.getPhotos.html>
	**/
	function onGroupsPoolsGetPhotos(group:Group)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onGroupsPoolsGetPhotos: flickr.groups.pools.getPhotos response");
			LogWrapper.getLog().info(group);
		}
	}
	/**
	* Function: onGroupsPoolsRemove
	* 
	* Called when there is a response from a call to flickr.groups.pools.remove
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		- 	The <Photo> you have just added to a <Group>.
	* group			-	The <Group> you have just added the <Photo> to.
	* 
	* See Also:
	* <Flickr.groupsPoolsAdd>
	* 
	* <http://flickr.com/services/api/flickr.groups.pools.remove.html>
	**/
	function onGroupsPoolsRemove(photo:Photo, group:Group)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onGroupsPoolsRemove: flickr.groups.pools.remove response");
			LogWrapper.getLog().info(photo);
			LogWrapper.getLog().info(group);
		}
		
	}
	
// /flickr.groups.pools methods

// flickr.people methods
	/**
	* Function: onPeopleFindByEmail
	* 
	* Called when there is a response from a call to flickr.people.findByEmail.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person 		- 	A <Person> object containing information about the person 
	* 					you found.
	* 
	* See Also:
	* <Flickr.peopleFindByEmail>
	* 
	* <http://flickr.com/services/api/flickr.people.findByEmail.html>
	**/
	function onPeopleFindByEmail(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleFindByEmail: flickr.people.findByEmail response");
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onPeopleFindByUsername
	* 
	* Called when there is a response from a call to flickr.people.findByUsername.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person 		- 	A <Person> object containing information about the person you found 
	* 
	* See Also:
	* <Flickr.peopleFindByUsername>
	* 
	* <http://flickr.com/services/api/flickr.people.findByUsername.html>
	**/
	function onPeopleFindByUsername(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleFindByUsername: flickr.people.findByUsername response");
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onPeopleGetInfo
	* 
	* Called when there is a response from a call to flickr.people.getInfo.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person 		- 	A <Person> object containing information about the person you found 
	* 				  	(nsid, isAdmin, isPro, username, realname, location, photosFirstDateTaken, 
	* 				  	photosFirstDate and numPhotos).
	* 
	* See Also:
	* <Flickr.peopleGetInfo>
	* 
	* <http://flickr.com/services/api/flickr.people.getInfo.html>
	**/
	function onPeopleGetInfo(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleGetInfo: flickr.people.getInfo response");
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onPeopleGetPublicGroups
	* 
	* Called when there is a response from a call to flickr.people.getPublicGroups.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person 		- 	A <Person> object representing the person whose groups you wanted info on
	* 
	* See Also:
	* <Flickr.peopleGetPublicGroups>
	* 
	* <Person.getGroups>
	* 
	* <http://flickr.com/services/api/flickr.people.getPublicGroups.html>
	**/
	function onPeopleGetPublicGroups(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleGetPublicGroups: flickr.people.getPublicGroups response");
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onPeopleGetPublicPhotos
	* 
	* Called when there is a response from a call to flickr.people.getPublicPhotos.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person		- 	The <Person> whose public photos you have got.
	* 
	* See Also:
	* <Flickr.peopleGetPublicPhotos>
	* 
	* <Person._photos>
	* 
	* <http://flickr.com/services/api/flickr.people.getPublicPhotos.html>
	**/
	function onPeopleGetPublicPhotos(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleGetPublicPhotos: flickr.people.getPublicPhotos response");
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onPeopleGetUploadStatus
	* 
	* Called when there is a response from a call to flickr.people.getUploadStatus.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person		- 	The <Person> whose upload status you have got (e.g. the currently
	* 					auth'd user).
	* 
	* See Also:
	* <Flickr.peopleGetUploadStatus>
	* 
	* <Person.bandwidthMax>
	* 
	* <Person.bandwidthUsed>
	* 
	* <Person.filesizeMax>
	* 
	* <http://flickr.com/services/api/flickr.people.getUploadStatus.html>
	**/
	function onPeopleGetUploadStatus(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPeopleGetUploadStatus: flickr.people.getUploadStatus response");
			LogWrapper.getLog().info(person);
		}
	}
// /flickr.people methods
	
	
// flickr.photos methods
	/**
	* Function: onPhotosAddTags
	* 
	* Called when there is a response from a call to flickr.photos.addTags.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			-	The <Photo> that the tags were added to.
	* tags 			-	The tags that were added. 
	* 
	* See Also:
	* <Flickr.photosAddTags>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.addTags.html>
	**/
	function onPhotosAddTags(photo:Photo, tags:String) 
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onPhotosAddTags: flickr.photos.addTags response: tags:\"" + tags + "\" added to photo: "+photo.id;
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetAllContexts
	* 
	* Called when there is a response from a call to flickr.people.getAllContexts.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		-	The <Photo> whose contexts you have just got
	* 
	* See Also:
	* <Photo.getPhotosets>
	* 
	* <Photo.getGroupPools> TODO: implement this!
	* 
	* <http://flickr.com/services/api/flickr.photos.getAllContexts.html>
	**/
	function onPhotosGetAllContexts(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetAllContexts: flickr.photos.getAllContexts response");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetContactsPhotos
	* 
	* Called when there is a response from a call to flickr.people.getContactsPhotos.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Note that Flickr.getFlickr().authUser will point to the auth'd user and any contacts
	* that photos were found for whill have been added to that <Person>s contact list.
	* 
	* Parameters:
	* photos 		-	An array of <Photo> objects - one for each photo by a contact of 
	* 					the calling user
	* 
	* See Also:
	* <Flickr.photosGetContactsPhotos>
	* 
	* <http://flickr.com/services/api/flickr.photos.getContactsPhotos.html>
	**/
	function onPhotosGetContactsPhotos(photos:Array)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.getContactsPhotos: flickr.photos.getContactsPhotos response";
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photos);
			LogWrapper.getLog().info(Flickr.getFlickr().authUser);
		}
	}
	/**
	* Function: onPhotosGetContactsPublicPhotos
	* 
	* Called when there is a response from a call to flickr.people.getContactsPhotos.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person		-	The <Person> whose contacts public photos you requested
	* photos 		-	An array of <Photo> objects - one for each photo by a contact of the calling user
	* 
	* See Also:
	* <Flickr.photosGetContactsPublicPhotos>
	* 
	* <http://flickr.com/services/api/flickr.photos.getContactsPublicPhotos.html>
	**/
	function onPhotosGetContactsPublicPhotos(person:Person, photos:Array)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.getContactsPublicPhotos: flickr.photos.getContactsPhotos response for user: "+person.nsid;
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(person);
			LogWrapper.getLog().info(photos);
		}
	}
	/**
	* Function: onPhotosGetContext
	* 
	* Called when there is a response from a call to flickr.people.getContext.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			-	The <Photo> we were getting the context for. The values of context* will
	* 				  	be set in it and will point to the relevant other <Photo> objects
	* 
	* See Also:
	* <Flickr.photosGetContext>
	* 
	* <http://flickr.com/services/api/flickr.photos.getContext.html>
	**/
	function onPhotosGetContext(photo:Photo)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onPhotosGetContext: flickr.photos.getContext response (count="+photo.contextCount+")";
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetCounts
	* 
	* Called when there is a response from a call to flickr.people.getCounts.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* counts		-	An array containing objects for each date range getCounts was called on
	* 					Each object contains the following attributes: count, fromdate and todate
	* 
	* See Also:
	* <Flickr.photosGetCounts>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getCounts.html>
	**/
	function onPhotosGetCounts(counts:Array)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onPhotosGetCounts: flickr.photos.getCounts response:";
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(counts);
		}
	}
	/**
	* Function: onPhotosGetExif
	* 
	* Called when there is a response from a call to flickr.people.getExif.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			-	A <Photo> containing all the information loaded from flickr.com
	* 
	* See Also:
	* <Flickr.photosGetExif>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getExif.html>
	**/
	function onPhotosGetExif(photo:Photo)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onPhotosGetExif: flickr.photos.getExif response:";
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetInfo
	* 
	* Called when there is a response from a call to flickr.people.getInfo.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	A <Photo> containing all the information loaded from flickr.com
	* 
	* See Also:
	* <Flickr.photosGetInfo>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getInfo.html>
	**/
	function onPhotosGetInfo(photo:Photo)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onPhotosGetInfo: flickr.photos.getInfo response:";
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetNotInSet
	* 
	* Called when there is a response from a call to flickr.people.getPhotosNotInSet.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photos		- 	An Array of <Photo>'s.
	* 
	* See Also:
	* <Flickr.photosGetNotInSet>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getNotInSet.html>
	**/
	function onPhotosGetNotInSet(photos:Array)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetNotInSet: flickr.photos.getNotInSet response:");
			LogWrapper.getLog().info(photos);
		}
	}
	/**
	* Function: onPhotosGetPerms
	* 
	* Called when there is a response from a call to flickr.people.getPerms.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> that you just got permissions for.
	* 
	* TODO:
	* Need to actually do something with the permissions that were returned. At the moment
	* they are ignored as I need to figure out how to store permissions which are a combination
	* of <Person> and <Photo> - 
	* and so can't just be stored on a <Photo>.
	* 
	* See Also:
	* <Flickr.photosGetPerms>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getPerms.html>
	**/
	function onPhotosGetPerms(photo:Array)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetPerms: flickr.photos.getPerms response:");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetRecent
	* 
	* Called when there is a response from a call to flickr.people.getRecent.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photos		- 	An Array of <Photo>'s.
	* 
	* See Also:
	* <Flickr.photosGetNotInSet>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getRecent.html>
	**/
	function onPhotosGetRecent(photos:Array)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetRecent: flickr.photos.getRecent response:");
			LogWrapper.getLog().info(photos);
		}
	}
	/**
	* Function: onPhotosGetSizes
	* 
	* Called when there is a response from a call to flickr.people.getSizes.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> whose sizes you got.
	* 
	* See Also:
	* <Flickr.photosGetSizes>
	* 
	* <Photo._sizes>
	* 
	* <PhotoSize>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getSizes.html>
	**/
	function onPhotosGetSizes(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetSizes: flickr.photos.getSizes response:");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosGetUntagged
	* 
	* Called when there is a response from a call to flickr.people.getUntagged.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photos		- 	An Array of <Photo>'s.
	* 
	* See Also:
	* <Flickr.photosGetUntagged>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.getUntagged.html>
	**/
	function onPhotosGetUntagged(photos:Array)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosGetUntagged: flickr.photos.getUntagged response:");
			LogWrapper.getLog().info(photos);
		}
	}
	/**
	* Function: onPhotosRemoveTag
	* 
	* Called when there is a response from a call to flickr.people.removeTag.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Note that Flickr.getFlickr().authUser will point to the auth'd user who is 
	* obviously the person who removed the Tag if you are interested in that.
	* 
	* Parameters:
	* tagId			-	The ID of the <Tag> that was removed. This identifies a <Tag> and a
	* 					<Photo> it was associated with...
	* 
	* See Also:
	* <Flickr.photosRemoveTag>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.removeTag.html>
	**/
	function onPhotosRemoveTag(tagId:Number)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosRemoveTag: flickr.photos.removeTag response: tag "+tagId);
		}
	}
	/**
	* Function: onPhotosSearch
	* 
	* Called when there is a response from a call to flickr.people.search.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photos		- 	An Array of <Photo>'s.
	* 
	* See Also:
	* <Flickr.photosSearch>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.search.html>
	**/
	function onPhotosSearch(photos:Array)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosSearch: flickr.photos.search response:");
			LogWrapper.getLog().info(photos);
		}
	}
	/**
	* Function: onPhotosSetDates
	* 
	* Called when there is a response from a call to flickr.people.setDates.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> whose dates have just been updated,
	* 
	* See Also:
	* <Flickr.photosSetDates>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.setDates.html>
	**/
	function onPhotosSetDates(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosSetDates: flickr.photos.setDates response:");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosSetMeta
	* 
	* Called when there is a response from a call to flickr.people.setMeta.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> whose meta info has just been updated,
	* 
	* See Also:
	* <Flickr.photosSetMeta>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.setMeta.html>
	**/
	function onPhotosSetMeta(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosSetMeta: flickr.photos.setMeta response:");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosSetPerms
	* 
	* Called when there is a response from a call to flickr.people.setPerms.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> whose permissions info has just been updated,
	* 
	* See Also:
	* <Flickr.photosSetMeta>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.setPerms.html>
	**/
	function onPhotosSetPerms(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosSetPerms: flickr.photos.setPerms response:");
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onPhotosSetTags
	* 
	* Called when there is a response from a call to flickr.people.setTags.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			- 	The <Photo> whose tags have just been updated,
	* 
	* See Also:
	* <Flickr.photosSetTags>
	* 
	* <http://www.flickr.com/services/api/flickr.photos.setTags.html>
	**/
	function onPhotosSetTags(photo:Photo)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosSetTags: flickr.photos.setTags response:");
			LogWrapper.getLog().info(photo);
		}
	}
	
// /flickr.photos methods

// flickr.photosets methods

	/**
	* Function: onPhotosetsAddPhoto
	* 
	* Called when there is a response from a call to flickr.photosets.addPhoto
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset			-	The photoset the photo was added to. The added photo will be the
	* 						last one in <photoset.photos>
	* 
	* See Also:
	* <Flickr.photosetsAddPhoto>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.addPhoto.html>
	**/
	function onPhotosetsAddPhoto(photoset:Photoset) 
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsAddPhoto: flickr.photosets.addPhoto response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsCreate
	* 
	* Called when there is a response from a call to flickr.photosets.create
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset			-	The newly created <Photoset>
	* 
	* See Also:
	* <Flickr.photosetsCreate>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.create.html>
	**/
	function onPhotosetsCreate(photoset:Photoset) 
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsAddPhoto: flickr.photosets.create response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsDelete
	* 
	* Called when there is a response from a call to flickr.photosets.delete
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photosetId		-	The id of the deleted photoset
	* 
	* See Also:
	* <Flickr.photosetsDelete>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.delete.html>
	**/
	function onPhotosetsDelete(photosetId:Number)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsDelete: flickr.photosets.delete response: Photoset "+photosetId+" deleted");
		}
	}
	/**
	* Function: onPhotosetsEditMeta
	* 
	* Called when there is a response from a call to flickr.photosets.editMeta
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset		-	The <Photoset> that you have just updated the meta info for...
	* 
	* See Also:
	* <Flickr.photosetsEditMeta>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.editMeta.html>
	**/
	function onPhotosetsEditMeta(photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsEditMeta: flickr.photosets.editMeta response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsEditPhotos
	* 
	* Called when there is a response from a call to flickr.photosets.editPhotos
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset		-	The <Photoset> that you have just updated the photos for...
	* 
	* See Also:
	* <Flickr.photosetsEditPhotos>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.editPhotos.html>
	**/
	function onPhotosetsEditPhotos(photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsEditPhotos: flickr.photosets.editPhotos response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsGetContext
	* 
	* Called when there is a response from a call to flickr.photosets.getContext
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo			-	The <Photo> that you have just got the context of.
	* photoset		-	The <Photoset> you got the context in.
	* 
	* See Also:
	* <Flickr.photosetsGetContext>
	* 
	* <Photo.contextPhotosets>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.getContext.html>
	**/
	function onPhotosetsGetContext(photo:Photo, photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsGetContext: flickr.photosets.getContext response:");
			LogWrapper.getLog().info(photo);
			LogWrapper.getLog().info(photoset);
		}
	} 
	/**
	* Function: onPhotosetsGetInfo
	* 
	* Called when there is a response from a call to flickr.photosets.getInfo
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset			-	The <Photoset> that you have just got info for...
	* 
	* See Also:
	* <Flickr.photosetsEditPhotos>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.getInfo.html>
	**/
	function onPhotosetsGetInfo(photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsGetInfo: flickr.photosets.getInfo response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsGetList
	* 
	* Called when there is a response from a call to flickr.photosets.getList
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user				-	The <Person> whose <Photoset>s you have just retrieved.
	* 
	* See Also:
	* <Flickr.photosetsGetList>
	* 
	* <Person.getPhotosets>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.getList.html>
	**/
	function onPhotosetsGetList(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsGetList: flickr.photosets.getList response:");
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onPhotosetsGetPhotos
	* 
	* Called when there is a response from a call to flickr.photosets.getPhotos
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset				-	The <Photoset> whose <Photo>s you have just retrieved.
	* 
	* See Also:
	* <Flickr.photosetsGetPhotos>
	* 
	* <Photoset.getPhotos>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.getPhotos.html>
	**/
	function onPhotosetsGetPhotos(photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsGetPhotos: flickr.photosets.getPhotos response:");
			LogWrapper.getLog().info(photoset);
		}
	}
	/**
	* Function: onPhotosetsOrderSets
	* 
	* Called when there is a response from a call to flickr.photosets.orderSets
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user				-	The <Person> whose <Photo>s you have just ordered (i.e. you!)
	* 
	* See Also:
	* <Flickr.photosetsOrderSets>
	* 
	* <Person.getPhotosets>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.orderSets.html>
	**/
	function onPhotosetsOrderSets(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsOrderSets: flickr.photosets.orderSets response:");
			LogWrapper.getLog().info(user);
		}
	}
	/**
	* Function: onPhotosetsRemovePhoto
	* 
	* Called when there is a response from a call to flickr.photosets.removePhoto
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photoset				-	The <Photoset> you have just removed a <Photo> from
	* 
	* See Also:
	* <Flickr.photosetsRemovePhoto>
	* 
	* <http://www.flickr.com/services/api/flickr.photosets.removePhoto.html>
	**/
	function onPhotosetsRemovePhoto(photoset:Photoset)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onPhotosetsRemovePhoto: flickr.photosets.removePhoto response:");
			LogWrapper.getLog().info(photoset);
		}
	}
// /flickr.photosets methods

// flickr.tags methods
	
	/**
	* Function: onTagsGetListPhoto
	* 
	* Called when there is a response from a call to flickr.tags.tagsGetListPhoto.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* photo 		-	The <Photo> whose tags are being returned. Use <Photo.getTags> to
	* 					get at the tags themselves...
	* 
	* See Also:
	* <Flickr.tagsGetListPhoto>
	* 
	* <Photo.getTags>
	* 
	* <http://www.flickr.com/services/api/flickr.tags.getListPhoto.html>
	**/
	function onTagsGetListPhoto(photo:Photo)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onTagsGetListPhoto: flickr.tags.getListPhoto response: photoId: "+photo.id;
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(photo);
		}
	}
	/**
	* Function: onTagsGetListUser
	* 
	* Called when there is a response from a call to flickr.tags.getListUser.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person		- 	The <Person> whose tags are being returned.
	* 
	* See Also:
	* <Flickr.tagsGetListUser>
	* 
	* <http://www.flickr.com/services/api/flickr.tags.getListUser.html>
	**/
	function onTagsGetListUser(person:Person)
	{
		if (!supressOutput) {
			var message:String = "FlickrResponseListener.onTagsGetListUser: flickr.tags.getListUser response for "+person.nsid;
			LogWrapper.getLog().info(message);
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onTagsGetListUserPopular
	* 
	* Called when there is a response from a call to flickr.tags.getListUserPopular.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* person		- 	The <Person> whose tags are being returned.
	* 
	* See Also:
	* <Flickr.tagsGetListUserPopular>
	* 
	* <http://www.flickr.com/services/api/flickr.tags.getListUserPopular.html>
	**/
	function onTagsGetListUserPopular(person:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onTagsGetListUser: flickr.tags.getListUser response for "+person.nsid);
			LogWrapper.getLog().info(person);
		}
	}
	/**
	* Function: onTagsGetRelated
	* 
	* Called when there is a response from a call to flickr.tags.tagsGetRelated.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* sourceTag		-	The tag you were getting related tags for - look in it's 
	* 					relatedTags Object.
	* 
	* See Also:
	* <Flickr.tagsGetRelated>
	* 
	* <Tag.relatedTags>
	* 
	* <http://www.flickr.com/services/api/flickr.tags.getRelated.html>
	**/
	function onTagsGetRelated(sourceTag:Tag)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onTagsGetRelated: flickr.tags.getRelated response");
			LogWrapper.getLog().info(sourceTag);
		}
	}
	
// /flickr.tags methods


// flickr.test methods
	
	/**
	* Function: onTestEcho
	* 
	* Called when there is a response from a call to flickr.test.echo.
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* params 		-	An object with containing all the echo'd variables.
	* 
	* See Also:
	* <Flickr.testEcho>
	* 
	* <http://www.flickr.com/services/api/flickr.test.echo.html>
	**/
	function onTestEcho(params:Object)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onTestEcho: flickr.test.echo response:");
			LogWrapper.getLog().info(params);
		}
	}
	
	/**
	* Function: onTestLogin
	* 
	* Called when there is a response from a call to flickr.test.login
	* 
	* Override this method in your application if you want to do something with the
	* response to this call.
	* 
	* Parameters:
	* user			-	A reference to the logged in user
	* 
	* See Also:
	* <Flickr.testLogin>
	* 
	* <http://www.flickr.com/services/api/flickr.test.login.html>
	**/
	function onTestLogin(user:Person)
	{
		if (!supressOutput) {
			LogWrapper.getLog().info("FlickrResponseListener.onTestLogin: flickr.test.login response:");
			LogWrapper.getLog().info(user);
		}
	}
	
// /flickr.test methods
	
	/**
	* Function: onError
	* 
	* Called when the Flickr API returns an error code..
	* 
	* Override this method in your application so that it deals with the error.
	* 
	* Parameters:
	* errorCode - The code of this error.
	* errorDescription - A description of this error.
	* method - The Flickr API method that was called when this error occured.
	*/
	function onError(errorCode:Number, errorDescription:String, method:String)
	{
		if (!supressOutput) {
			LogWrapper.getLog().error(errorCode+": "+errorDescription+" when calling '"+method+"'");
		}
	}
	
	/**
	* Function: onAPIResponse
	* 
	* Internal function which deals with a response from a Flickr API call and 
	* forwards any relevant arguments to the relevant function.
	* 
	* You shouldn't need to override this function.
	* 
	* Parameters:
	* eventObject - An object containing all the relevant information about the API call
	**/
	function onAPIResponse(eventObject:Object)
	{
		if (eventObject.status == Flickr.STATUS_OK) {
			switch (eventObject.method) {
				case "flickr.auth.getFrob":
					onAuthGetFrob(eventObject.frob);
					break;
				case "flickr.auth.getToken":
				case "flickr.auth.checkToken":
					onAuthCheckToken(eventObject.token);
					break;
				case "flickr.contacts.getList":
					onContactsGetList(eventObject.user, eventObject.filter);
					break;
				case "flickr.contacts.getPublicList":
					onContactsGetPublicList(eventObject.user);
					break;
				case "flickr.favorites.add":
					onFavoritesAdd(Photo.getPhoto(eventObject.photoId));
					break;
				case "flickr.favorites.getList":
					onFavoritesGetList(eventObject.user);
					break;
				case "flickr.favorites.getPublicList":
					onFavoritesGetPublicList(eventObject.user);
					break;
				case "flickr.favorites.remove":
					onFavoritesRemove(Photo.getPhoto(eventObject.photoId));
					break;
				case "flickr.groups.pools.add":
					onGroupsPoolsAdd(eventObject.photo, eventObject.group);
					break;
				case "flickr.groups.pools.getContext":
					onGroupsPoolsGetContext(eventObject.photo, eventObject.group);
					break;
				case "flickr.groups.pools.getGroups":
					onGroupsPoolsGetGroups(eventObject.user);
					break;
				case "flickr.groups.pools.getPhotos":
					onGroupsPoolsGetPhotos(eventObject.group);
					break;
				case "flickr.groups.pools.remove":
					onGroupsPoolsRemove(eventObject.photo, eventObject.group);
					break;
				case "flickr.people.findByEmail":
					onPeopleFindByEmail(eventObject.person);
					break;
				case "flickr.people.findByUsername":
					onPeopleFindByUsername(eventObject.person);
					break;
				case "flickr.people.getInfo":
					onPeopleGetInfo(eventObject.person);
					break;
				case "flickr.people.getPublicGroups":
					onPeopleGetPublicGroups(eventObject.person);
					break;
				case "flickr.people.getPublicPhotos":
					onPeopleGetPublicPhotos(eventObject.person);
					break;
				case "flickr.people.getUploadStatus":
					onPeopleGetUploadStatus(eventObject.user);
					break;
				case "flickr.photos.addTags":
					onPhotosAddTags(eventObject.photo, eventObject.tags);
					break;
				case "flickr.photos.getAllContexts":
					onPhotosGetAllContexts(eventObject.photo);
					break;
				case "flickr.photos.getContactsPhotos":
					onPhotosGetContactsPhotos(eventObject.contactsPhotos);
					break;
				case "flickr.photos.getContactsPublicPhotos":
					onPhotosGetContactsPublicPhotos(eventObject.user, eventObject.contactsPhotos);
					break;
				case "flickr.photos.getContext":
					onPhotosGetContext(eventObject.thisPhoto);
					break;
				case "flickr.photos.getCounts":
					onPhotosGetCounts(eventObject.photoCounts);
					break;
				case "flickr.photos.getExif":
					onPhotosGetExif(eventObject.photo);
					break;
				case "flickr.photos.getInfo":
					onPhotosGetInfo(eventObject.photo);
					break;
				case "flickr.photos.getNotInSet":
					onPhotosGetNotInSet(eventObject.photos);
					break;
				case "flickr.photos.getPerms":
					onPhotosGetPerms(eventObject.photo);
					break;
				case "flickr.photos.getRecent":
					onPhotosGetRecent(eventObject.photos);
					break;
				case "flickr.photos.getSizes":
					onPhotosGetSizes(eventObject.photo);
					break;
				case "flickr.photos.getUntagged":
					onPhotosGetUntagged(eventObject.photos);
					break;
				case "flickr.photos.removeTag":
					onPhotosRemoveTag(eventObject.tagId);
					break;
				case "flickr.photos.search":
					onPhotosSearch(eventObject.photos);
					break;
				case "flickr.photos.setDates":
					onPhotosSetDates(eventObject.photo);
					break;
				case "flickr.photos.setMeta":
					onPhotosSetMeta(eventObject.photo);
					break;
				case "flickr.photos.setPerms":
					onPhotosSetPerms(eventObject.photo);
					break;
				case "flickr.photos.setTags":
					onPhotosSetTags(eventObject.photo);
					break;
				case "flickr.photosets.addPhoto":
					onPhotosetsAddPhoto(eventObject.photoset);
					break;
				case "flickr.photosets.create":
					onPhotosetsCreate(eventObject.photoset);
					break;
				case "flickr.photosets.delete":
					onPhotosetsDelete(eventObject.photosetId);
					break;
				case "flickr.photosets.editMeta":
					onPhotosetsEditMeta(eventObject.photoset);
					break;
				case "flickr.photosets.editPhotos":
					onPhotosetsEditPhotos(eventObject.photoset);
					break;
				case "flickr.photosets.getContext":
					onPhotosetsGetContext(eventObject.photo, eventObject.photoset);
					break;
				case "flickr.photosets.getInfo":
					onPhotosetsGetInfo(eventObject.photoset);
					break;
				case "flickr.photosets.getList":
					onPhotosetsGetList(eventObject.photosetOwner);
					break;
				case "flickr.photosets.getPhotos":
					onPhotosetsGetList(eventObject.photoset);
					break;
				case "flickr.photosets.orderSets":
					onPhotosetsOrderSets(eventObject.user);
					break;
				case "flickr.photosets.removePhoto":
					onPhotosetsRemovePhoto(eventObject.photoset);
					break;
				case "flickr.tags.getListPhoto":
					onTagsGetListPhoto(eventObject.photo);
					break;
				case "flickr.tags.getListUser":
					onTagsGetListUser(eventObject.person);
					break;
				case "flickr.tags.getListUserPopular":
					onTagsGetListUserPopular(eventObject.person);
					break;
				case "flickr.tags.getRelated":
					onTagsGetRelated(eventObject.sourceTag);
					break;
				case "flickr.test.echo":
					onTestEcho(eventObject.params);
					break;
				case "flickr.test.login":
					onTestLogin(eventObject.user);
					break;
				default:
					LogWrapper.getLog().info("Got response for call to method "+eventObject.method+":\n"+eventObject.restXML);
			}
		} else {
			onError(eventObject.status, eventObject.errorMessage, eventObject.method);
		}
	}
	
	public function toString():String
	{
		return "[Object com.kelvinluck.flickr.FlickrResponseListener]";
	}
}
