﻿import com.kelvinluck.flickr.Flickr;
import com.kelvinluck.flickr.Person;
import com.kelvinluck.flickr.Note;
import com.kelvinluck.flickr.Tag;
import com.kelvinluck.flickr.PhotoSize;
import com.kelvinluck.util.LogWrapper;
import com.kelvinluck.util.DateFormat;
import com.kelvinluck.flickr.Photoset;
import com.kelvinluck.flickr.Group;

/**
* Class: com.kelvinluck.flickr.Photo
* Class to describe a photo from Flickr.
* 
* Instances of this class are created to hold photos who have been
* returned in data from calls to the Flickr API.
* 
* Author:
* Kelvin Luck < kelvin at kelvinluck dot com >
**/
class com.kelvinluck.flickr.Photo {
	
	/**
	* Variable: id
	* This photo's id.
	**/
	public var id:Number;
	/**
	* Variable: owner
	* A reference to the <Person> who owns this photo.
	**/
	public var owner:Person;
	/**
	* Variable: secret
	* This photo's secret.
	**/
	public var secret:String;
	/**
	* Variable: server
	* This photo's server.
	**/
	public var server:Number;
	/**
	* Variable: title
	* This photo's title.
	**/
	public var title:String;
	/**
	* Variable: description
	* This photo's description.
	**/
	public var description:String;
	/**
	* Variable: numComments
	* The number of comments this photo has.
	**/
	public var numComments:Number;
	/**
	* Variable: notes
	* The <Note>s that have been left on this photo. Private so access through the
	* functions below.
	* 
	* See Also:
	* <getNotes>
	* 
	* <addNote>
	**/
	private var _notes:Object;
	/**
	* Variable: _tags
	* The <Tag>s that are associated with this photo. Private so access through the
	* functions below.
	* 
	* See Also:
	* <getTags>
	* 
	* <addTag>
	**/
	var _tags:Object;
	/**
	* Variable: _sizes
	* The <PhotoSize>s that are associated with this photo. 
	* 
	* See Also:
	* <addSize>
	**/
	private var _sizes:Array;
	/**
	* Variable: isPublic
	* Whether or not this photo is public.
	**/
	public var isPublic:Boolean;
	
	// TODO - the following stuff isn't really relevant to a photo as such....
	// it should be stored as the relationship between the calling user and the
	// photo
	
	/**
	* Variable: isFriend
	* Whether or not this photo is by a friend.
	**/
	public var isFriend:Boolean;
	/**
	* Variable: isFamily
	* Whether or not this photo is by a family member.
	**/
	public var isFamily:Boolean;
	
	// /TODO comment about being about the relationship between the photo
	// and calling user rather than just the photo...
	
	/**
	* Variable: dateUploaded
	* The date this photo was uploaded
	* 
	* You set this as a String which the setter method automagically transforms from a
	* UNIX Timestamp (as provided by flickr.com) to a Date object.
	**/
	private var _dateUploaded:Date;
	public function set dateUploaded(date_str) 
	{
		_dateUploaded = new Date(date_str*1000);
	}
	public function get dateUploaded():Date
	{
		return _dateUploaded;
	}
	/**
	* Variable: dateTaken
	* The date this photo was taken.
	* 
	* You set this as a string which the setter method automagically transforms from a
	* MySQL Timestamp (as provided by flickr.com) to a Date object.
	**/
	private var _dateTaken:Date;
	public function set dateTaken(date_str) {
		_dateTaken = DateFormat.isoToDate(date_str);
	}
	public function get dateTaken():Date
	{
		return _dateTaken;
	}
	/**
	* Variable: dateUpdated
	* The date this photo was uploaded
	* 
	* You set this as a String which the setter method automagically transforms from a
	* UNIX Timestamp (as provided by flickr.com) to a Date object.
	**/
	private var _dateUpdated:Date;
	public function set dateUpdated(date_str) 
	{
		_dateUpdated = new Date(date_str*1000);
	}
	public function get dateUpdated():Date
	{
		return _dateUpdated;
	}
	/**
	* Variable: licence
	**/
	public var licence:Number;
	/**
	* Variable: rotation
	**/
	public var rotation:Number;
	/**
	* Variable: photoPageUrl
	* The link to this photo's page on flickr.com. If flickr.photos.getInfo has
	* been called on this photo then the link will be the "pretty" one with the
	* user's chosen screen name. Otherwise it will be the "ugly" one which works
	* just as well but doesn't look as good.
	**/
	private var _photoPageUrl:String;
	public function set photoPageUrl(photoPageUrl:String)
	{
		_photoPageUrl = photoPageUrl;
	}
	public function get photoPageUrl():String
	{
		if (_photoPageUrl) {
			return _photoPageUrl;
		}
		return "http://www.flickr.com/photos/"+owner.nsid+"/"+id+"/";
	}
	/**
	* Variable: thumbnailUrl
	* The URL for the thumbnail image representing this <Photo>
	**/
	private var _thumbnailUrl:String;
	public function set thumbnailUrl(thumbnailUrl:String) {
		// would not normally want to do this but photosetsGetContext returns it and we don't necessarily know
		// the images server at that point so can't generate the URL as we normally would...
		_thumbnailUrl = thumbnailUrl;
	}
	public function get thumbnailUrl():String
	{
		if (_thumbnailUrl) {
			return _thumbnailUrl;
		} else {
			//return "http://photos"+server+".flickr.com/"+id+"_"+secret+"_s.jpg";
			return "http://static.flickr.com/"+server+"/"+id+"_"+secret+"_s.jpg";
		}
	}
	/**
	* Variable: mediumUrl
	* The URL for the medium sized image (500px on longest side)
	**/
	public function set mediumUrl(mediumUrl:String) {}
	public function get mediumUrl():String
	{
		//return "http://photos"+server+".flickr.com/"+id+"_"+secret+".jpg";
		return "http://static.flickr.com/"+server+"/"+id+"_"+secret+".jpg";
	}
	
	// TODO - this is contextual again and so should not be stored with the Photo
	// but somewhere else refering to the photo object?
	
	/**
	* Variable: contextUrl
	* The URL for this photo within the context of the photostream e.g. as returned from
	* a call to flickr.photo.getContext
	**/
	public var contextUrl:String;
	/**
	* Variable: contextThumbUrl
	* The URL for this photo's thumbnail image within some sort of context e.g. as returned from
	* a call to flickr.photo.getContext
	* TODO: The thumbnail URL should be independant of context, no?
	**/
	public var contextThumbUrl:String;
	/**
	* Variable: contextPhotoPrevious
	* The previous photo in this context (as returned by <Flickr.photosGetContext>)
	**/
	public var contextPhotoPrevious:Photo;
	/**
	* Variable: contextPhotoNext
	* The next photo in this context (as returned by <Flickr.photosGetContext>)
	**/
	public var contextPhotoNext:Photo;
	/**
	* Variable: contextCount
	* Not documented on flickr.com but maybe the number of photos in this context (e.g. the user's photostream)?
	* (as returned by <Flickr.photoGetContext>)
	**/
	public var contextCount:Number;
	/**
	* Variable: contextPhotosets
	* Stores information about this <Photo>s context in given <Photoset>s
	* 
	* See Also:
	* <Flickr.photosetsGetContext>
	* 
	* <getContextPhotoset>
	* 
	* <setContextPhotoset>
	**/
	var contextPhotosets:Object;
	/**
	* Variable: contextGroupPool
	* Stores information about this <Photo>s context in given <Group>s
	* 
	* See Also:
	* <Flickr.groupsPoolsGetContext>
	* 
	* <getContextGroupPool>
	* 
	* <setContextGroupPool>
	**/
	var contextGroupPools:Object;
	
	// /TODO contextual comment above
	
	/**
	* Variable: _photosets
	* An Array containing references to the <Photoset>s that this <Photo> is in. Filled in by a call
	* to <Flickr.photosGetAllContexts> and also when you e.g. add a <Photo> to a <Photoset> through 
	* <Photoset.addPhoto> or <Flickr.photosetsEditPhotos>
	* 
	* See Also:
	* <addPhotoset>
	* 
	* <removePhotoset>
	* 
	* <getPhotosets>
	**/
	private var _photosets:Array;
	/**
	* Variable: _groups
	* An Array containing references to the <Group>s that this <Photo> is in. Filled in by a call to
	* <Flickr.photosGetAllContexts> and also when you e.g. add a <Photo> to a <Group> through
	* <Group.addPhoto>
	* 
	* See Also:
	* <addGroup>
	* 
	* <removeGroup>
	* 
	* <getGroups>
	**/
	var _groups:Array;
	
	/**
	* Variable: exifData
	* The EXIF/TIFF/GPS tags associated with this photo.
	* It is an Array of <ExifData> objects.
	**/
	public var exifData:Array;
	/**
	* Variable: _photos
	* A private static Object containing Photo objects. Used by <getPhoto> to insure that only 
	* one Photo is created for each photo ID returned from flickr.com
	**/
	private static var _photos:Object = {};
	
	/**
	* Function: Photo
	* Constructor function - creates a new Photo object.
	* 
	* Should be called via <Photo.getPhoto>
	**/
	private function Photo(id:Number)
	{
		LogWrapper.getLog().debug("com.kelvinluck.flickr.Photo instance created - id="+id);
		this.id = id;
		_notes = {};
		_tags = {};
		_sizes = [];
		contextPhotosets = {};
		_photosets = [];
		contextGroupPools = {};
		_groups = [];
	}
	
	/**
	* Function: getNotes
	* 
	* Returns an object containing all the note's that have been left on this
	* Photo
	* 
	* Returns:
	* All the <Note>'s that have been left on this Photo
	* 
	* See Also:
	* <_notes>
	* 
	* <Flickr.photosGetInfo>
	**/
	function getNotes():Object
	{
		return _notes;
	}
	
	/**
	* Function: addNote
	* Adds a <Note> object to this Photo.
	* 
	* Parameters:
	* note			-	The <Note> you want to add to this photo
	**/
	function addNote(note:Note):Void
	{
		if (_notes[note.id] == undefined) {
			_notes[note.id] = note;
		}
	}
	/**
	* Function: getTags
	* 
	* Returns an object containing all the tags's that are associated with this
	* Photo.
	* 
	* Returns:
	* All the <Tag>'s that are associated with this Photo. Each Tag is associated with
	* a <Person> as well &ndash; the <Person> who left this <Tag> on this <Photo>. Each <Tag> is
	* also associated with an id &ndash; this is the number you would use to call <Flickr.photosRemoveTag>
	* if you wanted to remove that <Tag> from this <Photo>.
	* 
	* See Also:
	* <_tags>
	* 
	* <Flickr.photosGetInfo>
	**/
	function getTags():Object
	{
		return _tags;
	}
	
	/**
	* Function: addTag
	* Adds a <Tag> object to this Photo and associates it with a <Person> who is the <Person> who
	* associated that <Tag> with this <Photo>.
	* 
	* Parameters:
	* id			-	The id which describes the link between this <Photo> and <Tag>.
	* tag			-	The <Tag> you want to add to this photo.
	* author		-	The <Person> who attached that <Tag> to this <Photo>.
	* 
	* See Also:
	* <_tags>
	* 
	* <getTags>
	**/
	function addTag(id:Number, tag:Tag, author:Person):Void
	{
		if (_tags[id] == undefined) {
			_tags[id] = {tag:tag, author:author, id:id};
		}
	}
	
	/**
	* Function: setTags
	* Set's this Photo's <_tags>...
	* 
	* Parameters:
	* tags			-	The tags to add to this photo...
	* author		-	The <Person> who added these tags (leave blank if you don't know)
	* 
	* TODO:
	* Doesn't deal properly with tags with spaces in the name now :(
	* 
	* Also need to get the <Person> object for the logged in user so we can correctly
	* associate the author with the tag...
	* 
	* We don't know the id's that will associate the <Tag>'s with the <Photo>s at this
	* point so are using garbage ones. This means that you won't be able to remove the
	* tags using those ids...
	**/
	function setTags(tags:String, author:Person)
	{
		_tags = {};
		var tagsSplit:Array = tags.split(" ");
		for (var i:Number=0; i<tagsSplit.length; i++) {
			var thisTag:Tag = Tag.getTag(tagsSplit[i]);
			// It would be good to call Tag.addPhoto at this stage but we don't know 
			// the id associating the Person with the Tag
			addTag(i, thisTag, author);
			Flickr.getFlickr().authUser.addTag(thisTag);
		}
	}
	/**
	* Function: addPhotoset
	* Adds a photoset to this <Photo>s <_photosets> Array
	* 
	* Parameters:
	* photoset				-	The <Photoset> to add to this <Photo>.
	**/
	function addPhotoset(photoset:Photoset)
	{
		for (var i:Number=0; i<_photosets.length; i++) {
			if (_photosets[i].id == photoset.id) {
				return;
			}
		}
		_photosets.push(photoset);
	}
	/**
	* Function: removePhotoset
	* Removes a given <Photoset> from this <Photo>s <_photosets> Array.
	**/
	function removePhotoset(photoset:Photoset)
	{
		for (var i:Number=0; i<_photosets.length; i++) {
			if (_photosets[i].id == photoset.id) {
				_photosets.splice(i, 1);
			}
		}
	}
	/**
	* Function: getPhotosets
	* 
	* Returns:
	* This <Photo>s <_photosets> Array.
	* 
	* See Also:
	* <_photosets>
	**/
	function getPhotosets():Array
	{
		return _photosets;
	}
	/**
	* Function: addGroup
	* Adds a <Group> to this <Photo>s <_groups> Array
	* 
	* Parameters:
	* group					-	The <Group> to add to this <Photo>.
	**/
	function addGroup(group:Group)
	{
		for (var i:Number=0; i<_groups.length; i++) {
			if (_groups[i].nsid == _groups.nsid) {
				return;
			}
		}
		_groups.push(group);
	}
	/**
	* Function: removeGroup
	* Removes a given <Group> from this <Photo>s <_groups> Array.
	**/
	function removeGroup(group:Group)
	{
		for (var i:Number=0; i<_groups.length; i++) {
			if (_groups[i].nsid == group.nsid) {
				_groups.splice(i, 1);
			}
		}
	}
	/**
	* Function: getGroups
	* 
	* Returns:
	* This <Group>s <_groups> Array.
	* 
	* See Also:
	* <_groups>
	**/
	function getGroups():Array
	{
		return _groups;
	}
	/**
	* Function: setContextPhotoset
	* Adds information about this <Photo>s context in a given <Photoset>
	* 
	* Parameters:
	* photosetId			-	The id of the <Photoset> this context is for
	* previousPhoto			-	The <Photo> before this <Photo> in this context or undefined if this
	* 							is the first <Photo> in this context.
	* nextPhoto				-	The <Photo> after this <Photo> in this context or undefined if this is
	* 							the last <Photo> in this context.
	**/
	function setContextPhotoset(photosetId:Number, previousPhoto:Photo, nextPhoto:Photo)
	{
		if (contextPhotosets[photosetId] == undefined) {
			contextPhotosets[photosetId] = {};
		}
		contextPhotosets[photosetId].previousPhoto = previousPhoto;
		contextPhotosets[photosetId].nextPhoto = nextPhoto;
	}
	/**
	* Function: getContextPhotoset
	* Get information about the context of this <Photo> in a given <Photoset>
	* 
	* Parameters:
	* photosetId			-	The id of the <Photoset> you want the context information for.
	* 
	* Returns:
	* An object containing nextPhoto and previousPhoto which are <Photo> objects. undefined if there is no
	* information about this <Photo>s context in the requested <Photoset>
	**/
	function getContextPhotoset(photosetId:Number)
	{
		return contextPhotosets[photosetId];
	}
	/**
	* Function: setContextGroupPool
	* Adds information about this <Photo>s context in a given <Group>
	* 
	* Parameters:
	* groupId				-	The id of the <Group> this context is for
	* previousPhoto			-	The <Photo> before this <Photo> in this context or undefined if this
	* 							is the first <Photo> in this context.
	* nextPhoto				-	The <Photo> after this <Photo> in this context or undefined if this is
	* 							the last <Photo> in this context.
	**/
	function setContextGroupPool(groupId:String, previousPhoto:Photo, nextPhoto:Photo)
	{
		if (contextGroupPools[groupId] == undefined) {
			contextGroupPools[groupId] = {};
		}
		contextGroupPools[groupId].previousPhoto = previousPhoto;
		contextGroupPools[groupId].nextPhoto = nextPhoto;
	}
	/**
	* Function: getContextGroupPool
	* Get information about the context of this <Photo> in a given <Photoset>
	* 
	* Parameters:
	* groupId				-	The id of the <Group> you want the context information for.
	* 
	* Returns:
	* An object containing nextPhoto and previousPhoto which are <Photo> objects. undefined if there is no
	* information about this <Photo>s context in the requested <Group>
	**/
	function getContextGroupPool(groupId:Number)
	{
		return contextGroupPools[groupId];
	}
	
	/**
	* Function: addSize
	* Adds a <PhotoSize> object to this Photo.
	* 
	* Parameters:
	* size			-	The <PhotoSize> you want to add to this photo.
	**/
	function addSize(size:PhotoSize):Void
	{
		_sizes.push(size);
	}
	
	
	/**
	* Function: getPhoto
	* Get's a Photo object for the given photo ID.
	* 
	* Consults <_photos> to make sure that only one Photo instance is created for each
	* photo ID from flickr.com
	* 
	* Parameters:
	* photoId		-	The id of the Photo you want to get
	**/
	public static function getPhoto(photoId:Number):Photo
	{
		if (_photos[photoId] == undefined) {
			_photos[photoId] = new Photo(photoId);
		}
		return _photos[photoId];
	}
	
	function toString():String
	{
		return "[Object com.kelvinluck.flickr.Photo - "+id+"]";
	}
}